@@ -5,6 +5,7 @@ use Moo;
 has mirror  => (is => 'rw');
 has index   => (is => 'rw');
 has cascade => (is => 'rw', default => sub { 1 });
+has without => (is => 'rw', default => sub { [] });
 
 sub effective_mirrors {
     my $self = shift;
@@ -51,11 +52,27 @@ sub install {
         ( $self->cascade ? "--cascade-search" : () ),
         ( $self->custom_mirror ? "--mirror-only" : () ),
         "--save-dists", "$path/cache",
-        "--with-develop",
+        $self->groups,
         "--installdeps", ".",
     ) or die "Installing modules failed\n";
 }
 
+sub groups {
+    my $self = shift;
+
+    my @options = ('--with-all-features', '--with-develop');
+
+    for my $group (@{$self->without}) {
+        if ($group eq 'develop') {
+            push @options, '--without-develop';
+        } else {
+            push @options, "--without-feature=$group";
+        }
+    }
+
+    return @options;
+}
+
 sub update {
     my($self, $path, @modules) = @_;
 
